/**
 * Created by jiachenpan on 16/11/18.
 */
export function getDefaultData() {
  const month = new Date().getMonth()
  const date = new Date()
  const end = new Date(`${month === 0 ? date.getFullYear() - 1 : date.getFullYear()}-${month === 0 ? '12' : month + 1}-&${date.getDate()} 09:00:00`)
  const start = new Date()
  start.setTime(end.getTime() - 3600 * 1000 * 24)
  return [parseTime(start, '{y}-{m}-{d} {h}:{i}:{s}'), parseTime(end, '{y}-{m}-{d} {h}:{i}:{s}')]
}

export function parseTime(time, cFormat) {
  if (arguments.length === 0) {
    return null
  }
  const format = cFormat || '{y}-{m}-{d} {h}:{i}:{s}'
  let date
  if (typeof time === 'object') {
    date = time
  } else {
    if (('' + time).length === 10) time = parseInt(time) * 1000
    date = new Date(time)
  }
  const formatObj = {
    y: date.getFullYear(),
    m: date.getMonth() + 1,
    d: date.getDate(),
    h: date.getHours(),
    i: date.getMinutes(),
    s: date.getSeconds(),
    a: date.getDay()
  }
  const time_str = format.replace(/{(y|m|d|h|i|s|a)+}/g, (result, key) => {
    let value = formatObj[key]
    // Note: getDay() returns 0 on Sunday
    if (key === 'a') { return ['日', '一', '二', '三', '四', '五', '六'][value ] }
    if (result.length > 0 && value < 10) {
      value = '0' + value
    }
    return value || 0
  })
  return time_str
}

export function formatTime(time, option) {
  time = +time * 1000
  const d = new Date(time)
  const now = Date.now()

  const diff = (now - d) / 1000

  if (diff < 30) {
    return '刚刚'
  } else if (diff < 3600) {
    // less 1 hour
    return Math.ceil(diff / 60) + '分钟前'
  } else if (diff < 3600 * 24) {
    return Math.ceil(diff / 3600) + '小时前'
  } else if (diff < 3600 * 24 * 2) {
    return '1天前'
  }
  if (option) {
    return parseTime(time, option)
  } else {
    return (
      d.getMonth() +
      1 +
      '月' +
      d.getDate() +
      '日' +
      d.getHours() +
      '时' +
      d.getMinutes() +
      '分'
    )
  }
}

/**
 * @param {Function} func
 * @param {number} wait
 * @param {boolean} immediate
 * @return {*}
 */
export function debounce(func, wait, immediate) {
  let timeout, args, context, timestamp, result

  const later = function() {
    // 据上一次触发时间间隔
    const last = +new Date() - timestamp

    // 上次被包装函数被调用时间间隔 last 小于设定时间间隔 wait
    if (last < wait && last > 0) {
      timeout = setTimeout(later, wait - last)
    } else {
      timeout = null
      // 如果设定为immediate===true，因为开始边界已经调用过了此处无需调用
      if (!immediate) {
        result = func.apply(context, args)
        if (!timeout) context = args = null
      }
    }
  }

  return function(...args) {
    context = this
    timestamp = +new Date()
    const callNow = immediate && !timeout
    // 如果延时不存在，重新设定延时
    if (!timeout) timeout = setTimeout(later, wait)
    if (callNow) {
      result = func.apply(context, args)
      context = args = null
    }

    return result
  }
}

/**
 * 创建并返回一个像节流阀一样的函数，当重复调用函数的时候，最多每隔delay毫秒调用一次该函数
 * @param func 执行函数
 * @param delay 时间间隔
 * @return {Function}
 */
export function throttle(func, delay) {
  let timeStamp = new Date()
  return function(...args) {
    const context = this
    if (new Date() - timeStamp > delay) {
      timeStamp = new Date()
      func.apply(context, args)
    }
  }
}

/**
 * @date 2019/11/22
 * @Description: 将中文转为unicode英文
 * @params1: text {string} 转化前的中文
 * @returns: 转化后的unicode
 */
export function transferEncodeText(text) {
  if (text == null) {
    return ''
  }
  var newText = ''
  for (var i = 0; i < text.length; i++) {
    var code = text.charCodeAt(i)
    if (code >= 128 || code == 91 || code == 93) {
      // 91 is "[", 93 is "]".
      newText += '[' + code.toString(16) + ']'
    } else {
      newText += text.charAt(i)
    }
  }
  return newText
}

/**
 * 行列转换
 * @param {array} arr
 * @return {array} res
 */
export function transformRowColumn(arr) {
  const res = []
  const firstItem = arr[0]
  for (let i = 0; i < arr.length; i++) {
    for (let j = 0; j < firstItem.length; j++) {
      if (!Array.isArray(res[j])) res[j] = []
      res[j].push(arr[i][j])
    }
  }
  return res
}

/**
 * 解决帆软报表有汉字参数的乱码
 * @param {string} text
 * @return {string} newText
 */
export function cjkEncode(text) {
  if (text == null) {
    return ''
  }
  var newText = ''
  for (var i = 0; i < text.length; i++) {
    var code = text.charCodeAt(i)
    if (code >= 128 || code === 91 || code === 93) { // 91 is "[", 93 is "]".
      newText += '[' + code.toString(16) + ']'
    } else {
      newText += text.charAt(i)
    }
  }
  return newText
}
